/*=============================================================================
XMOTO

This file is part of XMOTO.

XMOTO is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

XMOTO is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with XMOTO; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
=============================================================================*/

#ifndef __XMOTO_TEXT_H__
#define __XMOTO_TEXT_H__

#include <string>
#include <vector>

std::string txtToLower(const std::string &i_str);
std::string splitText(const std::string &str, int p_breakLineLength);
std::string formatTime(int i_time);
std::string unicode2utf8(unsigned int unicode);
std::string &replaceAll(std::string &context,
                        const std::string &from,
                        const std::string &to);
std::vector<std::string> splitStr(const std::string &string, char delim);

#endif
